<?php

/**
 * @license    GPL 2 (http://www.gnu.org/licenses/gpl.html)
 *
 * Estonian language file
 *
 * @author Werewolf <alvar@raamat.polva.ee>
 * @author kristian.kankainen <kristian.kankainen@kuu.la>
 * @author Rivo Zängov <eraser@eraser.ee>
 */
$lang['menu']                  = 'Seadete haldamine';
$lang['_configuration_manager'] = 'Seadete haldamine';
$lang['_basic']                = 'Peamised seaded';
$lang['_display']              = 'Näitamise seaded';
$lang['_authentication']       = 'Autentimise seaded';
$lang['_anti_spam']            = 'Spämmitõrje seaded';
$lang['_editing']              = 'Muudatuste seaded';
$lang['_links']                = 'Lingi seaded';
$lang['_media']                = 'Meedia seaded';
$lang['_advanced']             = 'Laiendatud seaded';
$lang['_network']              = 'Võrgu seaded';
$lang['title']                 = 'Wiki pealkiri';
$lang['template']              = 'Kujundus';
$lang['recent']                = 'Viimased muudatused';
$lang['signature']             = 'Allkiri';
$lang['passcrypt']             = 'Parooli krüptimismeetod';
$lang['defaultgroup']          = 'Vaikimisi grupp, kõik uued kasutajad lisatakse sellesse gruppi';
$lang['superuser']             = 'Superkasutaja - grupp, kasutaja või komaga eraldatud loetelu kasutaja1,@grupp1,kasutaja2 täielike pääsuõigustega lehekülgedele ja funktsioonidele, sõltumata ACL seadistustest';
$lang['disableactions_check']  = 'Kontrolli';
$lang['compression_o_0']       = 'pole';
$lang['compression_o_gz']      = 'gzip';
$lang['compression_o_bz2']     = 'bz2';
$lang['xsendfile_o_0']         = 'ära kasuta';
$lang['useheading_o_0']        = 'Mitte kunagi';
$lang['useheading_o_1']        = 'Alati';
